@@ -13,3 +13,6 @@ extern int selected_type,block_help_exit;
 extern int selected_type_cost,tech_level;
 extern char graphic_path[],helppath[];
 extern int load_flag;
+extern int lc_save_dir_len;
+extern char *askdir_path[4];
+extern int askdir_lines;
