@@ -27,13 +27,23 @@
 
 
 //                       ********   NOTE    VERSION
-#define VERSION 110
+#define VERSION 111
+#define VERSION_STRING "111"
 //                       ********   NOTE    VERSION
 
+
 #define MIN_LOAD_VERSION 97
 
 #define MM_MS_C_VER 97
 
+#if defined (WIN32)
+#define PATH_SLASH '\\'
+#define PATH_SLASH_STRING "\\"
+#else
+#define PATH_SLASH '/'
+#define PATH_SLASH_STRING "/"
+#endif
+
 #define THMO_TRANSPORT
 #define THMO_POLLUTION
 #define THMO_GP_STUFF
@@ -75,7 +85,7 @@
 
 // #define CS_PROFILE
 
-#ifdef LC_X11
+#if defined (LC_X11) || defined (WIN32)
 #define BORDERX 30
 #define BORDERY 30
 #endif
@@ -140,7 +150,11 @@
 
 #define SEED_RAND
 #define OLD_LC_SAVE_DIR "Lin-city"
+#if defined (WIN32)
+#define LC_SAVE_DIR "SAVED_GAMES"
+#else
 #define LC_SAVE_DIR ".Lin-city"
+#endif
 #define RESULTS_FILENAME "results"
 
 #define NUM_OF_TYPES 400
@@ -1011,6 +1025,7 @@ struct MAPPOINT {
 
 // main functions
 // **************
+extern int main(int, char**); // For WIN32
 extern void test(void);
 extern void do_error(char *);
 extern void clear_data(void);
@@ -1018,7 +1033,7 @@ extern void do_save_city(void);
 extern void remove_scene(char *);
 extern void save_city(char *);
 extern void do_load_city(void);
-extern void load_op_city(char *);
+extern void load_opening_city(char *);
 extern void load_city(char *);
 extern void reset_animation_times(void);
 extern void coal_reserve_setup(void);
@@ -1313,6 +1328,7 @@ extern void remove_a_shanty(void);
 extern void update_shanty(void);
 extern void do_shanty(int,int);
 extern void do_tip(int,int);
+extern void update_tech_dep(int,int);
 
 // transport functions
 // *******************
@@ -1412,14 +1428,34 @@ extern void Fgl_enableclipping(void);
 extern void Fgl_setclippingwindow(int,int,int,int);
 extern void Fgl_disableclipping(void);
 extern void open_setcustompalette(XColor *);
-
 #ifdef USE_X11_PIXMAPS
 #define USE_PIXMAPS
 extern void init_pixmaps(void);
 extern void init_icon_pixmap(int);
 extern void update_pixmap(int,int,int,int,int,int,int,char *);
 #endif
-#endif
+
+// WIN32 functions
+// *************
+#elif defined (WIN32)
+extern void gl_setpalettecolor(long,long,long,long);
+extern void Fgl_write(int,int,char *);
+extern void open_write(int,int,char *);
+extern void Fgl_getbox(int,int,int,int,void *);
+extern void Fgl_putbox(int,int,int,int,void *);
+extern void Fgl_fillbox(int,int,int,int,int);
+extern void Fgl_hline(int,int,int,int);
+extern void Fgl_line(int,int,int,int,int);
+extern void Fgl_setpixel(int,int,int);
+extern void Fgl_setfontcolors(int,int);
+extern void Fgl_enableclipping(void);
+extern void Fgl_setclippingwindow(int,int,int,int);
+extern void Fgl_disableclipping(void);
+#define USE_PIXMAPS /* Always */
+extern void init_pixmaps(void);
+extern void init_icon_pixmap(int);
+extern void update_pixmap(int,int,int,int,int,int,int,char *);
+#endif /* elif defined (WIN32) */
 
 
 // profiling
@@ -1439,7 +1475,7 @@ extern void update_pixmap(int,int,int,int,int,int,int,char *);
 
 #else
 
-#ifndef LC_X11
+#if !defined (LC_X11) && !defined (WIN32)
 #define Fgl_write(a,b,c) gl_write(a,b,c)
 #define Fgl_getbox(a,b,c,d,e) gl_getbox(a,b,c,d,e)
 #define Fgl_putbox(a,b,c,d,e) gl_putbox(a,b,c,d,e)
