@@ -1,4 +1,4 @@
-// screen.h   part of cim-sity
+// screen.h   part of lin-city
 // Copyright (c) I J Peters 1995,1996.  Please read the file 'COPYRIGHT'.
 
 extern struct TYPE main_types[];
@@ -119,5 +119,9 @@ extern int numof_shanties;
 extern int ex_tax_dis[];
 
 #ifdef USE_PIXMAPS
+#if defined (LC_X11)
 extern Pixmap icon_pixmap[];
+#elif defined (WIN32)
+extern HBITMAP icon_pixmap[];
+#endif
 #endif
