@@ -3,16 +3,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef LC_X11
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <X11/Xutil.h>
-#include "lcx11.h"
-#else
-#include <vga.h>
-#include <vgagl.h>
-#include <vgamouse.h>
-#endif
+#include "common.h"
 #include "lctypes.h"
 #include "lin-city.h"
 #include "transport.h"
