@@ -4,20 +4,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef LC_X11
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <X11/Xutil.h>
-#include "lcx11.h"
-#else
-#include <vga.h>
-#include <vgagl.h>
-#include <vgamouse.h>
-#endif
+#if !defined (WIN32)
 #include <strings.h>
-#ifdef SCO
+#endif
+#if defined (SCO) || defined (WIN32)
 #include <string.h>
 #endif
+#include "common.h"
 #include "lctypes.h"
 #include "lin-city.h"
 #include "typeinit.h"
